#!perl -T

use Test::More;

plan tests => 1;

diag( "Consider spawning  Password Safe GUI  to check how test.psafe3 looks like and whether it differs from sampledb/test.psafe3. Master password is 10101010" );

ok(1, "No op");
